16.54. cdist-type__git(7) — cdist 6.9.4 documentation

# 16.54. cdist-type__git(7)

## 16.54.1. NAME

cdist-type__git - Get and or keep git repositories up-to-date

## 16.54.2. DESCRIPTION

This cdist type allows you to clone git repositories

## 16.54.3. REQUIRED PARAMETERS

source

  Specifies the git remote to clone from

## 16.54.4. OPTIONAL PARAMETERS

state

  Either "present" or "absent", defaults to "present"

branch

  Create this branch by checking out the remote branch of this name Default branch is "master"

group

  Group to chgrp to.

mode

  Unix permissions, suitable for chmod.

owner

  User to chown to.

recursive

  Passes the --recurse-submodules flag to git when cloning the repository.

shallow

  Sets --depth=1 and --shallow-submodules for cloning repositories with big history.

## 16.54.5. EXAMPLES

    __git /home/services/dokuwiki --source git://github.com/splitbrain/dokuwiki.git

    # Checkout cdist, stay on branch 2.1
    __git /home/nico/cdist --source git@code.ungleich.ch:ungleich-public/cdist.git --branch 2.1

## 16.54.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.54.7. COPYING

Copyright (C) 2012 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.